@@ -10,16 +10,30 @@ check.dataform <- function(data) {
     stop("Data should contain at least two columns", call. = FALSE)
   data <- as.data.frame(data)
   mat <- sapply(data, is.matrix)
+  df  <- sapply(data, is.data.frame) 
   if (any(mat)) stop("Cannot handle columns with class matrix: ", 
                      colnames(data)[mat])
+  if (any(df)) stop("Cannot handle columns with class data.frame: ",
+                    colnames(data)[df])
   
   dup <- duplicated(colnames(data))
   if (any(dup)) stop("Duplicate names found: ", 
                      paste(colnames(data)[dup], collapse = ", "))
   
+  
   data
 }
 
+check.m <- function(m) {
+  m <- m[1L]
+  if (!is.numeric(m))
+    stop("Argument m not numeric", call. = FALSE)
+  m <- floor(m)
+  if (m < 1L)
+    stop("Number of imputations (m) lower than 1.", call. = FALSE)
+  m
+}
+
 check.cluster <- function(data, predictorMatrix) {
   # stop if the cluster variable is a factor
   isclassvar <- apply(predictorMatrix == -2, 2, any)
